@@ -46,15 +46,16 @@ Pyplot
 from collections import OrderedDict
 from IPython.display import display
 from ipywidgets import VBox
-from numpy import arange, issubdtype
+from numpy import arange, issubdtype, array, column_stack
 from .figure import Figure
 from .scales import Scale, LinearScale, Mercator
 from .axes import Axis
 from .marks import Lines, Scatter, Hist, Bars, OHLC, Pie, Map, Label
 from .toolbar import Toolbar
-from .interacts import (BrushIntervalSelector, FastIntervalSelector,
-                        BrushSelector, IndexSelector, MultiSelector,
-                        LassoSelector)
+from .interacts import (
+        BrushIntervalSelector, FastIntervalSelector, BrushSelector,
+        IndexSelector, MultiSelector, LassoSelector
+    )
 from traitlets.utils.sentinel import Sentinel
 
 Keep = Sentinel('Keep', 'bqplot.pyplot', '''
@@ -182,6 +183,7 @@ def figure(key=None, fig=None, **kwargs):
     # Used to automatically generate axis.
     if(getattr(_context['figure'], 'axis_registry', None) is None):
         setattr(_context['figure'], 'axis_registry', {})
+    return _context['figure']
 
 
 def close(key):
@@ -252,10 +254,12 @@ def scales(key=None, scales={}):
                               else old_ctxt[_get_attribute_dimension(k)] for k in scales}
     else:  # A key is provided
         if key not in _context['scale_registry']:
-            _context['scale_registry'][key] = {_get_attribute_dimension(k): scales[k]
-                                               if scales[k] is not Keep
-                                               else old_ctxt[_get_attribute_dimension(k)]
-                                               for k in scales}
+            _context['scale_registry'][key] = {
+                _get_attribute_dimension(k): scales[k]
+                if scales[k] is not Keep
+                else old_ctxt[_get_attribute_dimension(k)]
+                for k in scales
+            }
         _context['scales'] = _context['scale_registry'][key]
 
 
@@ -365,9 +369,9 @@ def grids(fig=None, value='solid'):
         a.grid_lines = value
 
 
-def hline(level, fig=None, preserve_domain=False, **kwargs):
+def hline(level, fig=None, **kwargs):
     """Draws a horizontal line at the given level.
-    
+
     Parameters
     ----------
     level: float
@@ -383,12 +387,21 @@ def hline(level, fig=None, preserve_domain=False, **kwargs):
     if fig is None:
         fig = current_figure()
     sc_x = fig.scale_x
-    plot([0., 1.], [level, level], scales={'x': sc_x}, preserve_domain={'x': True,
-         'y': preserve_domain}, axes=False, colors=default_colors,
-         stroke_width=default_width, update_context=False)
+
+    level = array(level)
+    if len(level.shape) == 0:
+        x = [0, 1]
+        y = [level, level]
+    else:
+        x = [0, 1]
+        y = column_stack([level, level])
+    return plot(x, y, scales={ 'x': sc_x }, preserve_domain={
+        'x': True,
+        'y': kwargs.get('preserve_domain', False)
+    }, axes=False, colors=default_colors, stroke_width=default_width, update_context=False, **kwargs)
 
 
-def vline(level, fig=None, preserve_domain=False, **kwargs):
+def vline(level, fig=None, **kwargs):
     """Draws a vertical line at the given level.
 
     Parameters
@@ -406,9 +419,19 @@ def vline(level, fig=None, preserve_domain=False, **kwargs):
     if fig is None:
         fig = current_figure()
     sc_y = fig.scale_y
-    plot([level, level], [0., 1.], scales={'y': sc_y}, preserve_domain={'x': preserve_domain,
-         'y': True}, axes=False, colors=default_colors,
-         stroke_width=default_width, update_context=False)
+
+    level = array(level)
+    if len(level.shape) == 0:
+        x = [level, level]
+        y = [0, 1]
+    else:
+        x = column_stack([level, level])
+        y = [[0, 1]] * len(level)  # TODO: repeating [0, 1] should not be
+                                   # required once we allow for 2-D x and 1-D y
+    return plot(x, y, scales={ 'y': sc_y }, preserve_domain={
+        'x': kwargs.get('preserve_domain', False),
+        'y': True
+    }, axes=False, colors=default_colors, stroke_width=default_width, update_context=False, **kwargs)
 
 
 def _draw_mark(mark_type, options={}, axes_options={}, **kwargs):
@@ -443,7 +466,7 @@ def _draw_mark(mark_type, options={}, axes_options={}, **kwargs):
         elif name in scales:
             if update_context:
                 _context['scales'][dimension] = scales[name]
-        # Scale has to be fetched from the conext or created as it has not
+        # Scale has to be fetched from the context or created as it has not
         # been passed.
         elif dimension not in _context['scales']:
             # Creating a scale for the dimension if a matching scale is not
@@ -453,10 +476,12 @@ def _draw_mark(mark_type, options={}, axes_options={}, **kwargs):
             dtype = traitlet.validate(None, kwargs[name]).dtype
             # Fetching the first matching scale for the rtype and dtype of the
             # scaled attributes of the mark.
-            compat_scale_types = [Scale.scale_types[key]
-                                  for key in Scale.scale_types
-                                  if Scale.scale_types[key].rtype == rtype and
-                                  issubdtype(dtype, Scale.scale_types[key].dtype)]
+            compat_scale_types = [
+                    Scale.scale_types[key]
+                    for key in Scale.scale_types
+                    if Scale.scale_types[key].rtype == rtype and
+                    issubdtype(dtype, Scale.scale_types[key].dtype)
+                ]
             sorted_scales = sorted(compat_scale_types, key=lambda x: x.precedence)
             scales[name] = sorted_scales[-1](**options.get(name, {}))
             # Adding the scale to the conext scales
